@@ -1,4 +1,4 @@
-/* $Id: value.cc 1760 2008-11-01 09:15:20Z jhs $ */
+/* $Id$ */
 // -*- C++ -*- //
 
 /* value.cc
@@ -6,16 +6,16 @@
  * Copyright 2006 libgdamm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
@@ -197,17 +197,23 @@ bool Value::operator!=(const Value& src) const
 
 
 Value::Value()
+:
+  Glib::ValueBase()
 {
   //Creates a null. TODO: Is this really equivalent to gda_value_new_null()?
 }
 
 Value::Value(const Value& src)
+:
+  Glib::ValueBase()
 {
   if(G_IS_VALUE(src.gobj()))
     init(src.gobj());
 }
 
 Value::Value(const GValue* castitem)
+:
+  Glib::ValueBase()
 {
   if(G_IS_VALUE(castitem))
     init(castitem);
@@ -433,6 +439,7 @@ void Value::set(const Glib::ustring& val)
 
 void Value::set(const char* val)
 {
+  value_reinit(gobj(), G_TYPE_STRING);
   g_value_set_string(gobj(), val);
 }
 
